'Build Version: 3.0.118.0
'***********************************************************************
' THIS CODE AND INFORMATION IS PROVIDED TO YOU FOR YOUR REFERENTIAL 
' PURPOSES ONLY, AND IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
' EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
' WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE, 
' AND MAY NOT BE REDISTRIBUTED IN ANY MANNER.
' 
' Copyright (c) 2004  Microsoft Corporation.  All rights reserved.
'***********************************************************************

'==========================================================================
'
' NAME: CreateShare.vbs
'
' COMMENT: Creates a Share given the following Parameters:
' Name ... The Share Name
' Path ... The local Path to the Share
' Trustee ... Name of the User or Group that will get Full Control on the Share (optional)
' Comment ... Share Comment (Optional)
' Class   ... Trustee Class can be UserAccount or Group
' The script uses WMI to accomplish the task if Path or Name are blank the script will not execute and return ErrorCode 2 (Parameter Invalid)
' Default Permissions for the Share are removed and replaced by the Account in the Trustee Value supplied.
' If trustee is empty the local Administrators Group will get Full Control
'
' Syntax:
' createshareDomainTrustee.vbs /path:c:\shareme /name:sharethis /trustee:administrators /comment:"test share
'==========================================================================
' Deal with the Arguments

	Const intMaximumAllowed = 1000      ' User limit
	strPassword = vbNull
	
	Const DISK_DRIVE = 0              ' Share type constant
	Const FULL_CONTROL = 2032127      ' AccessMask constant
	Const CHANGE_CONTROL = 1245631    ' AccessMask constant
	Const ACCESS_ALLOWED_ACETYPE = 0  ' AceType constant
	


Set oArgs = WScript.Arguments.Named

	If oArgs.Exists("name") And oArgs.Exists("path") Then
		strName = oArgs.Item("name")
		strPath = oArgs("path")
		'strClass = oArgs("class")
		If oArgs.Exists("trustee") Then 
			strTrustee = oArgs("trustee")
		Else 
			strTrustee = "Administrators"
		End If
		If oArgs.Exists("comment") Then strComment = oArgs("comment")
	else
		WScript.Echo "Invalid Arguments."
		WScript.Quit(2)
	End If
	
Set oNet = CreateObject("Wscript.Network")
strComputerName = oNet.ComputerName

If InStr(strTrustee,"\") then 
	strDomain = split(strtrustee,"\")(0)
	strUserName = split(strtrustee,"\")(1)
Else
	strDomain = oNet.ComputerName
	strUserName = strTrustee
End if
Set oTemp = GetObject("WinNT://" & strDomain & "/" & strUserName)
If IsObject(oTemp) Then
	strClass = oTemp.Class
	WScript.Echo "Object Found (" & oTemp.Class & ")"
	If strClass = "User" Then strClass = "UserAccount"
Else
	WScript.Echo "Object not found for Trustee."
	WScript.Quit
End if
	
msg = "Creating Share " & strName & " to Path " & strPath & ". Comment: " & strComment & " Trustee: " & strUserName & " Domain: " & strDomain
WScript.Echo msg

CreateShare strComputerName,strPath,strName,strComment,strUserName,strDomain,strClass


Public Function CreateShare(strComputer, strPath,strName,strDescription,strTrustee1,strDomain,strClass)    
	
	
	'**************************************************
	'* Connect to WMI on target computer
	'**************************************************
	Set objWMIService = GetObject("winmgmts:" & _
	    "{impersonationLevel=Impersonate}!\\" & strComputer & "\root\cimv2")
	
	'**************************************************
	'* Fetch Win32_SID instance for each trustee
	'**************************************************
	Set objUserAccount1 = objWMIService.Get("Win32_" & strClass & ".Domain='" & _
	                      strDomain & "',Name='" & strTrustee1 & "'")
	Set objSID1 = objWMIService.Get("Win32_SID='" & objUserAccount1.SID & "'")
	
'   Set objUserAccount2 = objWMIService.Get("Win32_Group.Domain='" & _
' 	                      strDomain & "',Name='" & strTrustee2 & "'")
' 	Set objSID2 = objWMIService.Get("Win32_SID='" & objUserAccount2.SID & "'")
	
	'**************************************************
	'* Create Win32_Trustee objects for access control entries
	'**************************************************
	Set objTrustee1 = objWMIService.Get("Win32_Trustee")
	objTrustee1.Domain    = objSID1.ReferencedDomainName
	objTrustee1.Name      = objSID1.AccountName
	objTrustee1.SID       = objSID1.BinaryRepresentation
	objTrustee1.SidLength = objSID1.SidLength
	objTrustee1.SIDString = objSID1.SID
	WScript.Echo "Adding SID: " & objSID1.SID
' 	Set objTrustee2 = objWMIService.Get("Win32_Trustee")
' 	objTrustee2.Domain    = objSID2.ReferencedDomainName
' 	objTrustee2.Name      = objSID2.AccountName
' 	objTrustee2.SID       = objSID2.BinaryRepresentation
' 	objTrustee2.SidLength = objSID2.SidLength
' 	objTrustee2.SIDString = objSID2.SID
	
	'**************************************************
	'* Create Win32_ACE objects for security descriptor
	'**************************************************
	Set objACE1 = objWMIService.Get("Win32_ACE")
	objACE1.Trustee    = objTrustee1
	objACE1.AccessMask = FULL_CONTROL 
	objACE1.AceType    = ACCESS_ALLOWED_ACETYPE
	objACE1.AceFlags   = 3
	
' 	Set objACE2 = objWMIService.Get("Win32_ACE")
' 	objACE2.Trustee    = objTrustee2
' 	objACE2.AccessMask = CHANGE_CONTROL
' 	objACE2.AceType    = ACCESS_ALLOWED_ACETYPE
	
	'**************************************************
	'* Create Win32_SecurityDescriptor object for share
	'**************************************************
	Set objSecurityDescriptor = objWMIService.Get("Win32_SecurityDescriptor")
	objSecurityDescriptor.DACL = Array(objACE1) ', objACE2)
	
	'**************************************************
	'* Create share
	'**************************************************
	Set objShare = objWMIService.Get("Win32_Share")
	intRetVal = objShare.Create(strPath, strName, DISK_DRIVE, intMaximumAllowed, _
	                            strDescription, strPassword, objSecurityDescriptor)
	WScript.Echo "Win32_Share Create Return Value: " & intRetVal
End Function
