'Build Version: 3.0.118.0
'***********************************************************************
' THIS CODE AND INFORMATION IS PROVIDED TO YOU FOR YOUR REFERENTIAL 
' PURPOSES ONLY, AND IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
' EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
' WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE, 
' AND MAY NOT BE REDISTRIBUTED IN ANY MANNER.
' 
' Copyright (c) 2004  Microsoft Corporation.  All rights reserved.
'***********************************************************************

Function Write(str2Write,strType)
' **********************************************************
' Function Write (str2Write,strType)
' Description: Write the str2Write String and the strType
'			   String to the LogFile and optional To
' 			   stdOut. Set vDebug in the Main Script to 1
'			   to print to stdOut
' In: str2Write ......  the main message String
'     strType   ......  the Message Type
'
' Out: none
' **********************************************************
	If vDebug = 1 Then 
		' Write the Message to the screen
		wscript.echo strType & ": " & str2Write
	else 
		' Write a Progress Dot to the screen
		wscript.stdOut.Write "."
	end If
	' Write the Message to the Logfile and include the Type and 
	' a Timestamp
	oLogF.WriteLine Now() & ": " & strType & ": " & str2Write
End Function

Function Finalize
' **********************************************************
' Function Finalize <none>
' Description: Record the elapsed Time, and write a footer
'			   to the log File, then close the logfile
' In: none
'
' Out: none
' **********************************************************
	elapse = Mid(CStr(Timer - t),1,5)
	Write "Script complete.",Err_INFO
	Write "It took " & elapse & " seconds to complete the task(s).",Err_INFO
	ologf.close
End Function

Function RunCaptured(strCMD,bReportErrors)
' **********************************************************
' Function RunCaptured(strCMD,bReportErrors)
' Description: Runs a Command and captures the Output
' 			   The Function returns the stdout.err and the full text that the command issued
' 			   to stdout.
' 			   it also displays all lines generated by the runnning script. to surpress it pass
' 			   bReportErrors = False to the function
' In: strCMD ...... the commandline to Execute
'     bReportErrors ..... a boolean determining if all the 
'						  output needs to be returned
'
' Out: an Array containing the Output of the Command line And
'	   the last line of the output
' **********************************************************
Dim strTemp
' if we did not get a commandline passed In
' fail completely
If strCMD = "" Then
	Write "No Command specified.",Err_FAIL
	Finalize
	WScript.Quit(1)
End If
' Create the Exec Object
Set oExec = wshShell.Exec(strCmd)
' Loop until the Excuted Command line stops
Do while not oExec.StdOut.AtEndOfStream
	' Read a line from stdOut
	strLineIn = oExec.StdOut.ReadLine
	' If we are asked to write the output to the log and
	' the screen (in debug mode)
	If bReportErrors Then Write strLineIn,Err_INFO
	' Create the temporary string
	If strTemp = "" Then 
		strTemp = strLineIn
	Else
		strTemp = strTemp & vbCRLF & strLineIn
	End if
	' Return the Output in an Array
	RunCaptured = Array(oExec.StdErr.ReadAll,strTemp)
Loop
End Function

Function SetACL(sDir,sTrustee,sMask,sType,sFlags,sDeleteTrustee)
' **********************************************************
' Function SetACL(sDir,sTrustee,sMask,sType,sFlags))
' Description: Sets an DACL on a Filesystem Object
' In: 	sDir ...... the Path to the Object
'		sTrustee	....	The user or Group to Set
'		sMask		....	The Access Mask as Defined in the
' 							Main Script
' 		sType		....	The dacl type either allow Or deny
' 		sFlags		....	The dacl inheritance flags
'       sDeleteTrustee .... Delete this Trustee from the acl
'                      .... can be an empty string
'
' Out: none
' **********************************************************
Dim sLine,sd,dacl
' Get the current Security Descriptor
Write "Setting ACL to " & sDir & " for " & sTrustee, Err_INFO
Set sd = sec.GetSecurityDescriptor("FILE://" & sDir)
' Get the DACL
Set dacl = sd.DiscretionaryAcl 
' Build a ACE string to send to CheckDupe
sLine = sTrustee & "|" & sMask & "|" & sType
' Check if the ACE is already on the dacl
' if not add it.
if CheckDupe(dacl,sline) = False Then
' 	add the Trustee to the ACE
	ace.Trustee = sTrustee
'	add the access Mask to the ACE
	ace.AccessMask = sMask 
'	add the Type to the ACE
	ace.AceType = sType
'	add the Flags to the ACE
	ace.AceFlags = sFlags 
' 	add the ACE to the DACL
	dacl.AddAce ace 
'	now remove any Trustee specified
    If sDeleteTrustee <> "" then
	    DeleteAce dacl,sDeleteTrustee
    end if
'	add the new dacl back to the Security Descriptor
	sd.DiscretionaryAcl = dacl 
'	Set the Security Descriptor to the Object
	sec.SetSecurityDescriptor sd 
else
	' If the ACE already exist put a note into the log
	write "ACE Already Present in DACL. Skipped.",Err_INFO
	Exit Function
end if
End Function

Function DeleteAce(dacl, TrusteeName)
'********************************************************************
'*
'* Function DeleteAce(dacl, TrusteeName)
'* Purpose: Delete an Access Control Entry (ACE) from an Access Control List.
'* Input:   	dacl			Access Control List (Object)
'*				TrusteeName		Name of the Trustee you want to delete
'*										 
'* Output:  None
'*
'********************************************************************
On Error Resume Next
' Bubble Any Error to the Calling Function.
	Dim oACE
	' Create a temp ACE Object
	Set oACE = CreateObject("AccessControlEntry")
		' Recurse through the ACL
		For Each oAce in dacl
			'Find the Trustee you are looking to delete.
			if (Trim(lcase(oAce.Trustee)) = Trim(lcase(TrusteeName))) Then
			    Write "Removing ACE for : " & oACE.Trustee

				' Delete the ACE from the ACL
				dacl.RemoveAce(oAce)
			End if
		Next
	' Kill Objects
	Set oACE	= Nothing
End Function

Function CheckDupe(oDACL,sLine)
' **********************************************************
' Function CheckDupe(oDACL,sLine)
' Description: Checks if a DACL contains a certain ACE To
'			   prevent duplicates ACEs
' In: 	oDACL		.... 	the current DACL
' 		sLine		....	The line containing the new ACE
'
' Out: True or False 
' **********************************************************
Dim x,tACE
' Set to False as the default
CheckDupe = False
' iterate to through the current DACL
For Each tACE In oDACL 
'  Build a string from the current ACE
   x = tace.Trustee & "|" & tACE.AccessMask & "|" & tACE.AceType
'  Compare with new ACE and if equal return true
   If x = sLine then CheckDupe = True
Next 

End Function

Function CheckCscript()
' ******************************************************************************
' Function: CheckCscript()
' Input			.... None
'		
' Output		.... None
'
' Description: 	Checks if we run in cscript Processor if not
'				relaunches script with cscript.exe
' 			    Uses the CMDLib Component that ships with 
'				Windows XP and Window Server 2003
' ****************************************************************************

' create the object for commom module
Dim Component
Dim UseCscriptErrorMessage

Set component = CreateObject( "Microsoft.CmdLib" )


' check if the commom module(CmdLib.wsc) is not registered
If Err.Number Then
    Err.Clear
    WScript.Echo(L_UnableToInclude_ErrorMessage)
    WScript.Quit(1)
End If

' set the scripting host to WScript
Set component.ScriptingHost = WScript.Application

' Check whether the script is run using CScript
If CInt(component.checkScript) <> CONST_CSCRIPT Then
    UseCscriptErrorMessage = L_UseCscript1_ErrorMessage & vbCRLF & _
                             ExpandEnvironmentString(L_UseCscript2_ErrorMessage) & vbCRLF & vbCRLF & _
                             L_UseCscript3_ErrorMessage & vbCRLF & _
                             L_UseCscript4_ErrorMessage & vbCRLF & vbCRLF & _
                             ExpandEnvironmentString(L_UseCscript5_ErrorMessage)
    WScript.Echo (UseCscriptErrorMessage)
    WScript.Quit(1)
End If

End Function

'******************************************************************************
'* Function: ExpandEnvironmentString()
'*
'* Purpose:  This function expands the environment variables.
'*
'* Input:    [in]   strOriginalString the string that needs expansion.
'* Output:   Returns ExpandedEnvironmentString
'*
'******************************************************************************

Private Function ExpandEnvironmentString(ByVal strOriginalString)

    ON ERROR RESUME NEXT
    Err.Clear

    ' Return the string.
    ExpandEnvironmentString = wshShell.ExpandEnvironmentStrings(strOriginalString)

End Function

Sub dBreak(strToShow)
' End script for Debugging
WScript.Echo strToShow
WScript.Quit
End Sub

'********************************************************************
'*
'* Function GetUniqueSamName(varUsername)
'* Purpose: Pass in a Name and it will return a Unique Username
'* Input:   	varUsername		Username of User  (String)
'*										
'* Output:  Unique Username (String)
'*
'********************************************************************
Function GetUniqueSamName(varUsername)
	Dim Counter, gotUniqueFlag, tempNewUsername,UserRS
	
	' Check to see if the Username passed is greater than 20 charactors.  If so, 
	'	then cut the user down to 17 charactors.  This give you space to add numeric 
	'	characters at the end of the username to make it unique (if needed).
	If Len(varUsername) >= 20 then varUsername = mid(varUsername,1,17)
		
	gotUniqueFlag = False
	On Error Resume Next
	tempNewUsername = varUserName
	Do while not gotUniqueFlag
		Write "Current SAM Name: " & tempNewUserName		
		Set UserRS = GetObject("WinNT://" & strServer & "/" & tempNewUsername & ",user")
			If Err = -2147022675 then
				gotUniqueFlag = True
				varUserName = tempNewUsername
				Exit Do
			Else
				Counter = Counter + 1
				tempNewUsername = varUsername & Counter
			End If
			Write "An Error occured in GetUniqueSAMName." & Err.Number, Err_FAIL
		' Kill the object after each search.
		Set UserRS  = Nothing
	Loop
	GetUniqueSamName = varUserName
End Function

'********************************************************************
'*
'* Function ParseResult(varResult,varErrorString)
'* Purpose: Pass in a Result and a String that identifies an Error 
'			and it will return True or False if the Error has occurred.
'* Input:  	varResult		Result as Array of Strings
'* 			varErrorString	String(s) to look for as Array
'*										
'* Output:  Boolean if Error has occured
'*
'********************************************************************
Function ParseResult(varResult,varErrorString)
If (IsArray(varResult)=true) And (IsArray(varErrorString)=true) Then
	ParseResult = False
	' iterate through varErrorString
	For Each ErrString In varErrorString
		' iterate through varResult
		For Each resultString In varResult
			If InStr(1,resultString,ErrString,vbTextCompare) Then
				ParseResult = True
				Exit Function
			End if
		Next
	Next

Else
	Write "Input was not an Array. Ignoring.",Err_WARNING
End if

End Function
'********************************************************************
'*
'* Function VerifyRootOU
'* Purpose: verify if the Customer Root OU exists in the current domain
'* Input:  	none
'*										
'* Output:  Boolean 
'*
'********************************************************************

Function VerifyRootOU()
On Error Resume Next
Dim tObj, tOU
Set tObj = GetObject("LDAP://RootDSE")
If IsObject(tObj) Then
    Set tOU = GetObject("LDAP://" & constCustomerContainer & "," & tObj.Get("defaultNamingContext"))
    If Not IsObject(tOU) Then
        VerifyRootOU = False
    Else
        VerifyRootOU = True
    End if
Else
    VerifyRootOU = False
End if

VerifyRootOU = True
End Function
