'Build Version: 3.0.118.0
'***********************************************************************
' THIS CODE AND INFORMATION IS PROVIDED TO YOU FOR YOUR REFERENTIAL 
' PURPOSES ONLY, AND IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
' EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
' WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE, 
' AND MAY NOT BE REDISTRIBUTED IN ANY MANNER.
' 
' Copyright (c) 2004  Microsoft Corporation.  All rights reserved.
'***********************************************************************

Function CreateDNS(strZone)
' **********************************************************
' Function CreateDNS (strZone)
' Description: Creates the DNS Records for the customer
'			   on a Windows Server 2003 based DNS Server
'			   using the DNSCMD.EXE tool from the Support Tools
'			   and the RunCaptured() Function from the HelperFunction.vbs Script
'			   creates a standard Primary (file based) zone
' 			   Creates A Records for WWW, FTP, mx
'			   creates the mx Record
' 
' In: strZone	....	the name of the Zone
' Out: none
' **********************************************************
	' TODO: Deal with the Result when an Error occurs.
	Write "Creating DNS Entries on " & strDNSServer,Err_INFO
	' Create the Commandline for the zone creation
	strCmdLine = "cmd /c dnscmd.exe " & strDNSServer & " /zoneadd " & strZone & " /primary"
	' Use RunCaptured() to execute the Commandline and catch the response
	varResult = RunCaptured(strCmdLine,True)
	If ParseResult(varResult,Array("failed","error")) = True Then
		Write "Creating the DNS Zone Failed.",Err_FAIL
	End if		
	' Create the Commandline for the www A Record
	strCmdLine = "cmd /c dnscmd.exe " & strDNSServer & " /recordadd " & strZone & " www A " & strIPAddress
	' Use RunCaptured() to execute the Commandline and catch the response
	varResult = RunCaptured(strCmdLine,True)
	If ParseResult(varResult,Array("failed","error")) = True Then
		Write "Creating the WWW A Record Failed.",Err_FAIL
	End if		
	' Create the Commandline for the ftp A Record
	strCmdLine = "cmd /c dnscmd.exe " & strDNSServer & " /recordadd " & strZone & " ftp A " & strIPAddress
	' Use RunCaptured() to execute the Commandline and catch the response
	varResult = RunCaptured(strCmdLine,True)
	If ParseResult(varResult,Array("failed","error")) = True Then
		Write "Creating the FTP A Record Failed.",Err_FAIL
	End if		
	' Create the Commandline for the mx A Record
	strCmdLine = "cmd /c dnscmd.exe " & strDNSServer & " /recordadd " & strZone & " mx A " & strIPAddress
	' Use RunCaptured() to execute the Commandline and catch the response	
	varResult = RunCaptured(strCmdLine,True)
	If ParseResult(varResult,Array("failed","error")) = True Then
		Write "Creating the Mailhost A Record Failed.",Err_FAIL
	End if		
	' Create the Commandline for the MX Record
	strCmdLine = "cmd /c dnscmd.exe " & strDNSServer & " /recordadd " & strZone & " mail mx 1 mx." & strCustomer
	' Use RunCaptured() to execute the Commandline and catch the response
	varResult = RunCaptured(strCmdLine,True)
	If ParseResult(varResult,Array("failed","error")) = True Then
		Write "Creating the DNS MX Record Failed.",Err_FAIL
	End if		
	Write "Done with DNS Settings.",Err_INFO
End Function

Function CreateUNCWeb(strServerName,strHostHeader,strSiteName,strIPAddress,strPort,bStartOnCreate,strWebPath, strLogPath,strUserName,strPassword)
' **********************************************************
' Function CreateUNCWeb(strServerName,strHostHeader,strSiteName,strIPAddress,strPort,bStartOnCreate,strWebPath, strLogPath,strUserName,strPassword)
' Description: Creates a Web site over an UNC path using the same functionality as the Windows provided iisweb.vbs
' 
' In:		strServerName	....	the Name of the WebServer
'			strHostHeader	....	the Host Header name
'			strSiteName		....	the name of the Web Site (displayed in IIS Admin)
' 			strIPAddress	....	the IP Address the Website is going to listen on
' 			strPort			....	The Port for the Site
' 			bStartOnCreate	....	Start the Site after successfull creation, or Not
' 			strWebPath		....	the Physical UNC Path to the sites content
' 			strLogPath		....	the Path to the Log Files for IIS
' 			strUserName		....	the UNC User Name
' 			strPassword		....	the UNC User's Password
' Out: 		strSitePath 	....	the IIS Path to the Site
' **********************************************************

' define Variables
Dim locatorObj
Dim providerObj
Dim serviceObj
Dim Bindings
Dim objPath
Dim strSiteObjPath
Dim vDirObj
Dim serverObj
Dim strServerObj
Dim strServerObjPath
Dim strSitePath

' Make connections to WMI, to the IIS namespace on the Server specified, and to the Web service.
set locatorObj = CreateObject("WbemScripting.SWbemLocator")
set providerObj = locatorObj.ConnectServer(strServerName, "root/MicrosoftIISv2")
set serviceObj = providerObj.Get("IIsWebService='W3SVC'")

' Build the binding object, which is a required parameter of the CreateNewSite method.
' the binding object contains the hostheader, ipaddress and port parameters.
' Use the SpawnInstance WMI method since we are creating a new instance of an object.
Bindings = Array(0)
Set Bindings(0) = providerObj.get("ServerBinding").SpawnInstance_()
Bindings(0).IP = strIPAddress
Bindings(0).Port = strPort
Bindings(0).Hostname = strHostHeader

' Create the new Web site using the CreateNewSite method of the IIsWebService object.
' the method returns the Site's object Path within IIS.
strSiteObjPath = serviceObj.CreateNewSite(strSiteName, Bindings, strWebPath)
' handle the error if any
If Err Then
	WScript.Echo "*** Error Creating Site: " & Hex(Err.Number) & ": " & Err.Description & " ***"
	WScript.Quit(1)
End If

' Now get the absolute ADSI Path for the site
' strSiteObjPath is in the format of IIsWebServer='W3SVC/1180970907'
' To parse out the absolute path, W3SVC/1180970907, use the SWbemObjectPath WMI object.
Set objPath = CreateObject("WbemScripting.SWbemObjectPath")
objPath.Path = strSiteObjPath
strSitePath = objPath.Keys.Item("")

' Set some properties on the root virtual directory which was created by CreateNewSite.
' Details about all the properties can be found on MSDN at
' http://msdn.microsoft.com/library/default.asp?url=/library/en-us/iissdk/iis/usingthemetabasereferencepages.asp
Set vdirObj = providerObj.Get("IIsWebVirtualDirSetting='" & strSitePath & "/ROOT'")
vdirObj.AuthFlags = 5 							' Set the Authentication to AuthNTLM + AuthAnonymous
vdirObj.EnableDefaultDoc = True					' enable the default docs default.htm, default.asp etc 
vdirObj.DirBrowseFlags = &H4000003E 			' Set the Directory Browsing Flags to show date, time, size, extension, longdate
vdirObj.AccessFlags = 513 						' Set the Access Control to read and script
vdirObj.AppFriendlyName = "Root Application" 	' Set the Application Default Name

' Save the new settings to the metabase
vdirObj.Put_()

' CreateNewSite does not start the server, so start it now if requested
If bStartOnCreate then 
	Set serverObj = providerObj.Get(strSiteObjPath)
	serverObj.Start
End If

' Use the SetLogPath Function to set the LogFile path
' This function is contained in provisioningfunctions.vbs
SetLogPath "IIS://" & strServerName & "/" & strSitePath,strLogPath
' Use the SetAnonUser Function to set the Anonymous user
' This function is contained in provisioningfunctions.vbs
SetAnonUser "IIS://" & strServerName & "/" & strSitePath, strUserName,strPassword
' Return the site Path to the caller
CreateUNCWeb = strSitePath
End Function

Function SetLogPath(strADSIPath,strPath)
' **********************************************************
' Function Function SetLogPath(strADSIPath,strPath)
' Description: Set the Log File Path on a given Website or FTP Site
' In: 	strADSIPath	....	the Path to the Website Object in IIS
'		strPath		....	the physical Path to the log Files
' Out: none
' **********************************************************

	' Set The Log File Path Property on a Web or FTP Site
	Write "Set Log File Properties to: " & strADSIPath & " = " & strPath,Err_INFO
	' Define Variables
	Dim tObject
	' Bind to the ADSI Object of the Site
	Set tObject = GetObject(strADSIPath)
	' Modify the LogFile Directory Parameter
	tObject.LogFileDirectory = strPath
	' Set the Logfile Properties
	tObject.LogExtFileFlags = 4194303
	' Commit the Changes to the IIS Metabase
	tObject.SetInfo
End Function

Function SetAnonUser(strADSIPath,strUser,strPassword)
' **********************************************************
' Function Function SetAnonUser(strADSIPath,strUser,strPassword)
' Description: 	Set the Anonymous User on a given Website or FTP Site
'				also sets the Authentication to Basic and Anonymous
'
' In: 	strADSIPath	....	the Path to the Website Object in IIS
'		strUser		....	the Anonymous User to Set
'							can be COMPUTER\User or DOMAIN\User
'		strPassword	....	the Password for the User							
' Out: none
' **********************************************************
	' Define the Variables
	Dim tObject
	Write "Set Anonymous Username and Password to " & strADSIPath,Err_INFO
	' Bind to the ADSI Object of the Site
	Set tObject = GetObject(strADSIPath)
	' Set the Username
	tObject.AnonymousUserName = strUser
	' Set the Password
	tObject.AnonymousUserPass = strPassword
	' set the Authentication to Anonymous and Basic
	tObject.AuthFlags = 3
	' Set the Logon Domain for basic to the Current Domain
	tObject.DefaultLogonDomain = "\"
	' Commit the changes to the IIS Metabase
	tObject.SetInfo
End Function

Sub WebCreate()
' **********************************************************
' Sub WebCreate()
' Description: 	main routine to create a website
'
' In:  none
' Out: none
' **********************************************************

	' Print Out the Information that will be used to create the site
	strWebPath = strPath & "\" & strCustomer	
	write "Creating Website:",Err_INFO
	write "WebServer: " & strServer,Err_INFO
	write "HostHeader: " & strHostHeader,Err_INFO
	write "Port: " & strPort,Err_INFO
	' if we use local user strWebPath needs to corespond to the strAdminSAMAccount Name
	' Need to fix up ACL Inheritance for the BUILTIN Users Group on the Websites Folder
	SetACL strPath,"USERS",GENERIC_READ,0,NO_PROPAGATE_INHERIT_ACE,""
	
	If bLocal = True Then 
		' we also need to make sure the LocalUser Folder exits and the Permissions are set
		' the localUser Folder ensures that we can isolate users in FTP using Usernames
		' check if the folder exists if not create it
		if NOT oFS.FolderExists(strPath & "\LocalUser") Then 
			' folder is missing we create it
			oFs.CreateFolder(strPath & "\LocalUser")
			' Setup Filesystem Security for the LocalUser Folder
			' SetACL is contained in HelperFunctions.vbs
			SetACL strPath & "\Localuser" ,"Administrators",GENERIC_ALL,0,OBJECT_INHERIT_ACE Or CONTAINER_INHERIT_ACE,""
			SetACL strPath & "\LocalUser" ,Left("I_" & Trim(strCustomer),20),GENERIC_READ,0,OBJECT_INHERIT_ACE Or CONTAINER_INHERIT_ACE,""
			SetACL strPath & "\LocalUser",Left("U_" & Trim(strCustomer),20),GENERIC_READ,0,OBJECT_INHERIT_ACE Or CONTAINER_INHERIT_ACE,""
			SetACL strPath & "\LocalUser","USERS",LIST_FOLDER,0,OBJECT_INHERIT_ACE Or CONTAINER_INHERIT_ACE,""
		End If
		' put together the Path to the Customer Folder
		strWebPath = strPath & "\LocalUser\" & strAdminSAMName
	End If
	' write out the web path
	write "Path: " & strWebPath,Err_INFO
	' Now we set up the Folder structure for the customer
	' verify if each of the folders exists if not create it
	if NOT oFS.FolderExists(strWebpath) then oFs.CreateFolder(strWebPath)
	if NOT oFS.FolderExists(strWebPath & "\web") then oFs.CreateFolder(strWebPath & "\web")
	if NOT oFS.FolderExists(strWebPath & "\web\content") then oFs.CreateFolder(strWebPath & "\web\content")
	if NOT oFS.FolderExists(strWebPath & "\logs") then oFs.CreateFolder(strWebPath & "\logs")
	
	' Now Set the Filesystem ACLs on the customer Root Folder and Propagate them down
	Write "Setting ACLs on Customer Folders.",Err_INFO
	' this one is the same for local and domain users
	SetACL strWebPath,"BUILTIN\Administrators",GENERIC_ALL,0,OBJECT_INHERIT_ACE Or CONTAINER_INHERIT_ACE Or NO_PROPAGATE_INHERIT_ACE,"BUILTIN\Users"
	' now verify if we are using local user if so 
	If bLocal = true then
		' we are using local users so we need to pick up the local accounts
		SetACL strWebPath,Left("IUSR_" & Trim(strCustomer),20),GENERIC_READ,0,OBJECT_INHERIT_ACE Or CONTAINER_INHERIT_ACE Or NO_PROPAGATE_INHERIT_ACE,"BUILTIN\Users"
		SetACL strWebPath,Left("UNC_" & Trim(strCustomer),20),GENERIC_READ,0,OBJECT_INHERIT_ACE Or CONTAINER_INHERIT_ACE Or NO_PROPAGATE_INHERIT_ACE,"BUILTIN\Users"
	Else
		' we are using domain users so we pick up the domain accounts
		SetACL strWebPath,Left("I_" & Trim(strCustomer),20),GENERIC_READ,0,OBJECT_INHERIT_ACE Or CONTAINER_INHERIT_ACE Or NO_PROPAGATE_INHERIT_ACE,"BUILTIN\Users"
		SetACL strWebPath,Left("U_" & Trim(strCustomer),20),GENERIC_READ,0,OBJECT_INHERIT_ACE Or CONTAINER_INHERIT_ACE Or NO_PROPAGATE_INHERIT_ACE,"BUILTIN\Users"
	End if
	' now set the admin account on the folders
	' We need to get the Sam Accountname of the Admins Group here
	' we do the same for the Users Group
	If bLocal = True Then
		' For the WinNT Provider it is the Name Attribute we need
		strAdminGroupName = oAdminGroup.Name
		strUserGroupName = oUserGroup.Name
	else
		' For the LDAP Provider it is the SamAccountName Attribute we need
		strAdminGroupName = oAdminGroup.SamAccountName
		strUserGroupName = oUserGroup.SamAccountName
	End if
	SetACL strWebPath,strAdminGroupName,MODIFY,0,OBJECT_INHERIT_ACE Or CONTAINER_INHERIT_ACE Or NO_PROPAGATE_INHERIT_ACE,"BUILTIN\Users"
	SetACL strWebPath,strUserGroupName,GENERIC_READ,0,OBJECT_INHERIT_ACE Or CONTAINER_INHERIT_ACE Or NO_PROPAGATE_INHERIT_ACE,"BUILTIN\Users"
	' Copy a Sample default Page to web Folder to make sure we can test the site
	oFS.CopyFile "C:\Scripts\samplepage\default.asp",strWebPath & "\web\content\default.asp",True
	
	' Need to determine if the site content is hosted on a UNC Path or not.
	' Since the standard windows Tools only support local Paths we had to creat the CreateUNCWeb Function.
	write "Creating Website " & strHostHeader,Err_INFO
	' Now really determine if we are goiing to UNC, UNC Paths always start with \\
	If Left(strWebPath,2) = "\\" Then
		' use the CreateUNCWeb Function from the ProvisioningFunctions.vbs script to create the Site
		strMetabasePath = CreateUNCWeb(strServer,strHostHeader,strCustomer,"",strPort,True,strWebPath & "\web\content",strWebPath & "\logs",strNETBIOSDomain & "\" & Left("I_" & Trim(strCustomer),20),strPassword )
	else
		' we can use the standard IISWeb.vbs script to create a local site
		' so we setup the commandline as a string
		strCmdLine = "cscript.exe //nologo " & strWinDir & "\system32\iisweb.vbs /create " & strWebPath & "\web\content " & strCustomer & " /d www." & strCustomer & " /b " & strPort
		' Run the commandline and capture the output in varResult so we can determine if we failed or succeeded.
		varResult = RunCaptured(strCmdLine,True)
		' define temporary variables for result handling
		Dim splitResult
		Dim iCount
		' split the first piece of the result array at the End of the Line 
		' and store it in a string Array called splitResult
		splitResult = Split(varResult(1),vbCRLF)
		' walk the string Array
		For  iCount = 0 To UBound(splitResult) - 1
			' read the first entry of the results
			strLineIn = splitResult(iCount)
			' check if we have the metabase path in this line
			' this is usually one of the last lines so we need to 
			' go through most of them
			If instr(1,strLineIn,"metabase path",vbTextCompare) then
				' now we found the path and can store it in the 
				' strMetabasePath variable for later use
				' we need to split this line because it has
				' the attributename in it too.
				strMetabasePath = Trim(split(strLineIn,"=")(1))
			end if
		next
	End If
	' Use the SetLogPath Function to set the LogFile path
	' This function is contained in provisioningfunctions.vbs
	SetLogPath "IIS://" & strServer & "/" & strMetaBasePath, strWebPath & "\logs"
	' make sure the log file folder exists and create it if needed
	if NOT oFS.FolderExists(strWebPath & "\logs\W3SVC" & Split(strMetaBasePath,"/")(1)) then oFs.CreateFolder(strWebPath & "\logs\W3SVC" & Split(strMetaBasePath,"/")(1))
	' now set the Admin Account with read permissions on the log file folder to enable FTP Download of the folder
	SetACL strWebPath & "\logs\W3SVC" & Split(strMetaBasePath,"/")(1),strAdminSAMName,GENERIC_READ,0,OBJECT_INHERIT_ACE Or CONTAINER_INHERIT_ACE Or NO_PROPAGATE_INHERIT_ACE,"BUILTIN\Users"
	' Use the SetAnonUser Function to set the Anonymous user
	' This function is contained in provisioningfunctions.vbs
	' make sure we use the right username for local or domain users
	If bLocal = False then
		SetAnonUser "IIS://" & strServer & "/" & strMetaBasePath, strNETBIOSDomain & "\" & 	Left("I_" & Trim(strCustomer),20),strPassword
	Else
		SetAnonUser "IIS://" & strServer & "/" & strMetaBasePath, strServer & "\" & Left("IUSR_" & Trim(strCustomer),20),strPassword
	End if
End Sub

Sub FTPCreate()
' **********************************************************
' Sub FTPCreate()
' Description: 	main routine to create a FTP Site
'				this Sub Routine does not implement creating a
'				UNC based FTP Site
' In:  none
' Out: none
' ********************************************************** 

	' Print Out the Information that will be used to create the site
	write "Creating FTP site:",Err_INFO
	write "WebServer: " & strServer,Err_INFO
	write "Customer: " & strCustomer,Err_INFO
	write "Path: " & strWebPath,Err_INFO
	
	' make sure the Folder structure exists. 
	if NOT oFS.FolderExists(strWebpath) Then 
		' it does not so we bail out
		Write "Could not create an FTP Site. No WebSite exists.",Err_FAIL
	Else
		' it does exist now we build a commandline based on local or domain users
		If bLocal = False then
			' command line for domain users
			strCmdLine = "cscript.exe //nologo " & strWinDir & "\system32\IIsFtpDr.vbs /create IsolatedFTP ftp." & strCustomer & " " & strWebPath
		Else
			' command line for local users
			strCmdLine = "cscript.exe //nologo " & strWinDir & "\system32\IIsFtpDr.vbs /create IsolatedFTP " & strAdminSAMName & " " & strWebPath
		End if
		' run the commandline and capture the output
		varResult = RunCaptured(strCmdLine,True)
		' here could be some error handling
	End if
End Sub

Sub FPSEAnonGroupCreate()
' **********************************************************
' Sub FPSEAnonGroupCreate()
' Description: 	sub routine to create the Anonymous Group For
'				FPSE. This is called from the CreateCustomer
'				routines.
'
' In:  none
' Out: none
' **********************************************************
	' extract the Website number from the Website Path
	strGroupSuffix = Mid(strMetabasePath,7)
	write "Creating Frontpage Group FPSE_" & strGroupSuffix,Err_INFO
	If bLocal = True Then
		' we create a local group 
		' we are reusing the oNewContainer Object from the Customer User Creation
		Set oNewGroup = oNewContainer.Create("group","FPSE_" & strGroupSuffix)
		' Commit the changes to the SAM Database
		oNewGroup.Setinfo
	Else
		' we create a domain group
		' we are reusing the oNewContainer Object from the Customer User Creation
		Set oNewGroup = oNewContainer.Create("group","cn=FPSE_" & strGroupSuffix)
		' set the SAM Account Name for the group
		oNewGroup.SamAccountName = "FPSE_" & strGroupSuffix
		' Commint the Changes to AD
		onewGroup.SetInfo
	End if
End Sub

Sub FPSEExtend()
' **********************************************************
' Sub FPSEExtend()
' Description: 	sub routine to extend a site with Frontpage
'				Server extensions.
'
' In:  none
' Out: none
' **********************************************************

	write "Installing Frontpage Server Extensions",Err_INFO
	write "Webserver: " & strHostHeader,Err_INFO
	' to extend the website with FPSE we need to use OWSADM.EXE because
	' FPSE 2002 does not offer an object modes to manage sites.
	' OWSADM.EXE is always at the location below so it is OK to Hardcode the Path.
	' Check for the existence of OWSADM.EXE if it is not there FPSE have not been installed. 
	' We need to raise an error and Fail.
	If Not oFS.FileExists("C:\Program Files\Common Files\Microsoft Shared\web server extensions\50\bin\owsadm.exe") Then
		Write "FrontPage Server Extensions 2002 are not installed on server " & strServer &  ".",Err_FAIL
		Write "The Website will not be extended.",Err_FAIL
		Exit Sub
	end if
	' The commandlines will be different for local and domain users
	If bLocal = False then
		' build the domain user command line
		strCmdLine = "cmd.exe /c ""C:\Program Files\Common Files\Microsoft Shared\web server extensions\50\bin\owsadm.exe"" -o " & _
					 "install -p " & strPort & " -m " & strHostHeader & " -t msiis -u " & strNETBIOSDomain & "\" & strAdminSAMName
	Else
		' build the local user commandline
		strCmdLine = "cmd.exe /c ""C:\Program Files\Common Files\Microsoft Shared\web server extensions\50\bin\owsadm.exe"" -o " & _
					 "install -p " & strPort & " -m " & strHostHeader & " -t msiis -u " & strServer & "\" & strAdminSAMName
	End If
	' run the commandline and ignore the output because
	' OWSADMIN does not really return a valid message to stdOUT 
	' so we do not want to display the empty lines.
	varResult = RunCaptured(strCmdLine,False)
	' Verify FPSE have been installed
	If oFS.FolderExists(strWebPath & "\web\content\_vti_pvt") Then
		' assume FPSE has been installed
		Write "Site " & strHostHeader & " has been extended.", Err_Success
	Else
		Write "Site " & strHostHeader & " has not been extended.", Err_FAIL
	End if
End Sub

Sub MailCreate()
' **********************************************************
' Sub MailCreate()
' Description: 	sub routine to create the POP3 mailbox 
'				and the SMTP domain
'
' In:  none
' Out: none
' **********************************************************
	' to create the mailbox and the SMTP Domain we are 
	' using the WINPOP.EXE Commandline tool that ships
	' with Windows Server 2003 and is installed when 
	' the POP3 service is installed
	write "Creating MailDomain:" & strCustomer,Err_INFO
	write "MailServer: " & strMailServer,Err_INFO
	' Build the commandline to create the domain
	strCmdLine = "cmd.exe /c winpop.exe add " & strCustomer
	' Run the Commandline
	varResult = RunCaptured(strCmdLine,True)
	' depending if we use local or domain users we need to 
	' build a different command line
	If bLocal = False then
		' Create the commandline for domain users
		write "Creating MailBox For user admin@" & strCustomer,Err_INFO
		write "MailServer: " & strMailServer,Err_INFO
		strCmdLine = "cmd.exe /c winpop.exe add admin@" & strCustomer
	Else
		' Create the commandline for local users
		write "Creating MailBox For user " & strAdminSAMName,Err_INFO
		write "MailServer: " & strMailServer,Err_INFO
		strCmdLine = "cmd.exe /c winpop.exe add " & strAdminSAMName & "@" & strCustomer
	End If
	' run the command line
	varResult = RunCaptured(strCmdLine,True)
End Sub
